.. django-fabfile documentation master file, created by
   sphinx-quickstart on Sun Aug 28 17:19:42 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-fabfile's documentation!
==========================================

Contents:

.. toctree::
   :maxdepth: 2

   README
   backup
   instances
   security_groups
   switchdb
   useradd
   utils

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

